Module framing

Module framing 

NETCONF message framing layer.

Handles encoding outbound XML into framed bytes and decoding inbound bytes back into complete XML messages. Two framing modes:

  • EOM (NETCONF 1.0): Messages terminated by ]]>]]>
  • Chunked (NETCONF 1.1): Messages split into length-prefixed chunks

The framing mode is selected by the Session after the <hello> exchange.

Modules

chunked
NETCONF 1.1 chunked framing (RFC 6242 4.2).
eom
NETCONF 1.0 end-of-message framing.

Traits

Framer
Trait for encoding/decoding NETCONF message frames.